@@ -29,6 +29,10 @@ class PluggableTestProgram(unittest.TestProgram):
     :param buffer: *IGNORED*
     :param plugins: List of additional plugin modules to load
     :param excludePlugins: List of plugin modules to exclude
+    :param extraHooks: List of hook names and plugin *instances* to
+                       register with the session's hooks system. Each
+                       item in the list must be a 2-tuple of
+                       (hook name, plugin instance)
 
     .. attribute :: sessionClass
 
@@ -68,6 +72,7 @@ class PluggableTestProgram(unittest.TestProgram):
     defaultPlugins = ('nose2.plugins.loader.discovery',
                       'nose2.plugins.loader.testcases',
                       'nose2.plugins.loader.functions',
+                      'nose2.plugins.loader.testclasses',
                       'nose2.plugins.loader.generators',
                       'nose2.plugins.loader.parameters',
                       'nose2.plugins.result',
@@ -82,8 +87,10 @@ class PluggableTestProgram(unittest.TestProgram):
     def __init__(self, **kw):
         plugins = kw.pop('plugins', [])
         exclude = kw.pop('excludePlugins', [])
+        hooks = kw.pop('extraHooks', [])
         self.defaultPlugins = list(self.defaultPlugins)
         self.excludePlugins = list(self.excludePlugins)
+        self.extraHooks = hooks
         self.defaultPlugins.extend(plugins)
         self.excludePlugins.extend(exclude)
         super(PluggableTestProgram, self).__init__(**kw)
@@ -100,6 +107,7 @@ class PluggableTestProgram(unittest.TestProgram):
 
         # XXX force these? or can it be avoided?
         self.testLoader = self.loaderClass(self.session)
+        self.session.testLoader = self.testLoader
 
         # Parse initial arguments like config file paths, verbosity
         self.setInitialArguments()
@@ -167,7 +175,8 @@ class PluggableTestProgram(unittest.TestProgram):
         command line.
 
         """
-        logging.basicConfig(level=util.parse_log_level(cfg_args.log_level))
+        self.session.logLevel = util.parse_log_level(cfg_args.log_level)
+        logging.basicConfig(level=self.session.logLevel)
         log.debug('logging initialized %s', cfg_args.log_level)
         if cfg_args.verbose:
             self.session.verbosity += cfg_args.verbose
@@ -210,15 +219,26 @@ class PluggableTestProgram(unittest.TestProgram):
         self.session.hooks.handleArgs(events.CommandLineArgsEvent(args=args))
 
     def loadPlugins(self):
-        """Load available plugins"""
+        """Load available plugins
+
+
+        ``self.defaultPlugins`` and ``self.excludePlugins`` are passed
+        to the session to alter the list of plugins that will be
+        loaded.
+
+        This method also registers any (hook, plugin) pairs set in
+        ``self.hooks``. This is a good way to inject plugins that fall
+        outside of the normal loading procedure, for example, plugins
+        that need some runtime information that can't easily be
+        passed to them through the configuration system.
+
+        """
         self.session.loadPlugins(self.defaultPlugins, self.excludePlugins)
+        for method_name, plugin in self.extraHooks:
+            self.session.hooks.register(method_name, plugin)
 
     def createTests(self):
         """Create top-level test suite"""
-        # XXX belongs in init?
-        if self.module and '__unittest' in dir(self.module):
-            self.module = None
-
         event = events.CreateTestsEvent(
            self.testLoader, self.testNames, self.module)
         result = self.session.hooks.createTests(event)
@@ -241,7 +261,20 @@ class PluggableTestProgram(unittest.TestProgram):
         runner = self.runnerClass(self.session)
         event = events.RunnerCreatedEvent(runner)
         self.session.hooks.runnerCreated(event)
+        self.session.testRunner = event.runner
         return event.runner
 
 
-main_ = PluggableTestProgram
+main = PluggableTestProgram
+
+
+def discover(*args, **kwargs):
+    """Main entry point for test discovery.
+
+    Running discover calls :class:`nose2.main.PluggableTestProgram`,
+    passing through all arguments and keyword arguments **except module**:
+    ``module`` is discarded, to force test discovery.
+
+    """
+    kwargs['module'] = None
+    return main(*args, **kwargs)
