@@ -46,6 +46,8 @@ import unittest
 from nose2 import exceptions, util
 from nose2.events import Plugin
 from nose2.compat import unittest as ut2
+from nose2.plugins.loader.testclasses import MethodTestCase
+
 
 log = logging.getLogger(__name__)
 __unittest = True
@@ -53,11 +55,11 @@ __unittest = True
 
 class ParamsFunctionCase(ut2.FunctionTestCase):
     def __init__(self, name, func, **args):
-        self._name = name
+        self._funcName = name
         ut2.FunctionTestCase.__init__(self, func, **args)
 
     def __repr__(self):
-        return self._name
+        return self._funcName
 
     id = __str__ = __repr__
 
@@ -67,6 +69,9 @@ class Parameters(Plugin):
     alwaysOn = True
     configSection = 'parameters'
 
+    def registerInSubprocess(self, event):
+        event.pluginClasses.append(self.__class__)
+
     def getTestCaseNames(self, event):
         """Generate test case names for all parameterized methods"""
         log.debug('getTestCaseNames %s', event)
@@ -82,6 +87,9 @@ class Parameters(Plugin):
             # generate the methods to be loaded by the testcase loader
             self._generate(event, name, method, testCaseClass)
 
+    def getTestMethodNames(self, event):
+        return self.getTestCaseNames(event)
+
     def loadTestsFromModule(self, event):
         """Load tests from parameterized test functions in the module"""
         module = event.module
@@ -110,22 +118,26 @@ class Parameters(Plugin):
             # we can't find it - let the default case handle it
             return
 
-        parent, obj, name, index = result
+        parent, obj, fqname, index = result
         if not hasattr(obj, 'paramList'):
             return
 
-        if (index is None
-            and not isinstance(parent, type)
-            and not isinstance(obj, types.FunctionType)):
+        if (index is None and not
+            isinstance(parent, type) and not
+            isinstance(obj, types.FunctionType)):
             log.debug("Don't know how to load parameterized tests from %s", obj)
             return
 
-        if (parent
-            and isinstance(parent, type)
-            and issubclass(parent, unittest.TestCase)):
+        if (parent and
+            isinstance(parent, type) and
+            issubclass(parent, unittest.TestCase)):
             # generator method
-            names = self._generate(event, name, obj, parent)
+            names = self._generate(event, obj.__name__, obj, parent)
             tests = [parent(n) for n in names]
+        elif (parent and
+              isinstance(parent, type)):
+            names = self._generate(event, name, obj, parent)
+            tests = [MethodTestCase(parent)(name) for name in names]
         else:
             # generator func
             tests = list(self._generateFuncTests(obj))
