@@ -3,12 +3,11 @@ import os.path
 import tempfile
 import shutil
 import sys
-import subprocess
 
 import six
 
 from nose2.compat import unittest
-from nose2 import main, util
+from nose2 import discover, util
 
 
 HERE = os.path.abspath(os.path.dirname(__file__))
@@ -167,7 +166,7 @@ class NotReallyAProc(object):
     def communicate(self):
         with self:
             try:
-                self.result = main.PluggableTestProgram(
+                self.result = discover(
                     argv=('nose2',) + self.args, exit=False,
                     **self.kwargs)
             except SystemExit as e:
@@ -180,3 +179,25 @@ class NotReallyAProc(object):
 
     def poll(self):
         return not self.result.result.wasSuccessful()
+
+
+# mock multprocessing Connection
+class Conn(object):
+    def __init__(self, items):
+        self.items = items
+        self.sent = []
+        self.closed = False
+
+    def recv(self):
+        if self.closed:
+            raise EOFError("closed")
+        try:
+            return self.items.pop(0)
+        except:
+            raise EOFError("EOF")
+
+    def send(self, item):
+        self.sent.append(item)
+
+    def close(self):
+        self.closed = True
